[![codecov](https://codecov.io/gh/laminlabs/lamindb-setup/branch/main/graph/badge.svg)](https://codecov.io/gh/laminlabs/lamindb-setup)

# lamindb-setup: Setup LaminDB

- Stable user docs: [lamin.ai/docs/setup/](https://lamin.ai/docs/setup/)
- Latest developer docs: [netlify](https://lndb-htry.netlify.app/docs/lndb/)
